@@ -5,7 +5,7 @@
 #	   / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
 #	  /_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
 #
-#		ALACORDER beta 7 (pure-python)
+#		ALACORDER beta 7.3.7 (pure-python)
 #		Does not require cython or c compiler
 #
 #		by Sam Robson
@@ -30,7 +30,7 @@ from io import StringIO
 
 pd.options.display.float_format = '${:,.2f}'.format
 
-def config(in_path: str, out_path: str, flags="", print_log=True, warn=False, set_batch=0): 
+def config(in_path: str, out_path: str, flags="", print_log=True, warn=False, save_archive=False, set_batch=0): 
 
 	# Get extensions
 	out_ext: str = out_path.split(".")[-1].strip()
@@ -114,7 +114,8 @@ def config(in_path: str, out_path: str, flags="", print_log=True, warn=False, se
 		'batchsize': batchsize,
 		'print_log': print_log,
 		'warnings': warn,
-		'flags': flags
+		'flags': flags,
+		'save_archive': save_archive
 	})
 	
 	return conf
@@ -189,6 +190,7 @@ def writeTables(conf):
 	warn = conf['warnings']
 	contents = conf['contents']
 	batches = conf['batches']
+	save_archive = conf['save_archive']
 	if warn == False:
 		warnings.filterwarnings("ignore")
 	start_time = time.time()
@@ -197,10 +199,24 @@ def writeTables(conf):
 
 	fees = pd.DataFrame({'CaseNumber': '', 'Code': '', 'Payor': '', 'AmtDue': '', 'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
 	charges = pd.DataFrame({'CaseNumber': '', 'Num': '', 'Code': '', 'Felony': '', 'Conviction': '', 'CERV': '', 'Pardon': '', 'Permanent': '', 'Disposition': '', 'CourtActionDate': '', 'CourtAction': '', 'Cite': '', 'TypeDescription': '', 'Category': '', 'Description': ''},index=[0]) 
+	arch = pd.DataFrame({'Path':'','AllPagesText':'','Timestamp':''},index=[0])
+
 	for i, c in enumerate(batches):
-		exptime = time.time()
 		b = pd.DataFrame()
 		b['AllPagesText'] = pd.Series(c).map(lambda x: getPDFText(x))
+		exptime = time.time()
+		if save_archive == True:
+			timestamp = exptime
+			ar = pd.DataFrame({
+				'Path': c,
+				'AllPagesText': b['AllPagesText'],
+				'Timestamp': timestamp
+				},index=range(0,batchsize))
+			arch = pd.concat([arch, ar],ignore_index=True)
+			arch.fillna('',inplace=True)
+			arch.dropna(inplace=True)
+			arch.to_pickle(path_out+".pkl.xz",compression="xz")
+
 		b['CaseInfoOutputs'] = b['AllPagesText'].map(lambda x: getCaseInfo(x))
 		b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
 		b['Name'] = b['CaseInfoOutputs'].map(lambda x: x[1])
@@ -301,7 +317,6 @@ def writeTables(conf):
 		else:
 			raise Exception("Output file extension not supported! Please output to .xls, .pkl, .json, or .csv")
 		on_batch += 1
-		console_log(conf, on_batch,exptime,'Exporting detailed case information to table...')
 	log_complete(conf, start_time)
 	on_batch = 0
 
@@ -374,7 +389,6 @@ def writeFees(conf):
 		else:
 			raise Exception("Output file extension not supported! Please output to .xls, .json, or .csv")
 		on_batch += 1
-		console_log(conf, on_batch,exptime,'Parsing fee sheets to table...')
 	log_complete(conf, start_time)
 	on_batch = 0
 
@@ -396,9 +410,7 @@ def writeCharges(conf):
 	start_time = time.time()
 	on_batch = 0
 	outputs = pd.DataFrame()
-
-	fees = pd.DataFrame({'CaseNumber': '', 'Code': '', 'Payor': '', 'AmtDue': '', 'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
-	charges = pd.DataFrame({'CaseNumber': '', 'Num': '', 'Code': '', 'Felony': '', 'Conviction': '', 'CERV': '', 'Pardon': '', 'Permanent': '', 'Disposition': '', 'CourtActionDate': '', 'CourtAction': '', 'Cite': '', 'TypeDescription': '', 'Category': '', 'Description': ''},index=[0]) # charges = pd.DataFrame() # why is this here
+	charges = pd.DataFrame({'CaseNumber': '', 'Num': '', 'Code': '', 'Felony': '', 'Conviction': '', 'CERV': '', 'Pardon': '', 'Permanent': '', 'Disposition': '', 'CourtActionDate': '', 'CourtAction': '', 'Cite': '', 'TypeDescription': '', 'Category': '', 'Description': ''},index=[0]) 
 	for i, c in enumerate(batches):
 		exptime = time.time()
 		b = pd.DataFrame()
@@ -406,7 +418,6 @@ def writeCharges(conf):
 		b['CaseInfoOutputs'] = b['AllPagesText'].map(lambda x: getCaseInfo(x))
 		b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
 		b['ChargesOutputs'] = b.index.map(lambda x: getCharges(b.loc[x].AllPagesText, b.loc[x].CaseNumber))
-
 		charges['Num'] = charges['Num'].map(lambda x: pd.to_numeric(x,'ignore'))
 
 		chargetabs = b['ChargesOutputs'].map(lambda x: x[17])
@@ -507,7 +518,6 @@ def write(conf, method, status=''):
 		if print_log == True and out_ext != "no_export":
 			print(alloutputs)
 		on_batch += 1
-		console_log(conf, on_batch,exptime,status)
 
 		if out_ext == "xls":
 			with pd.ExcelWriter(path_out) as writer:
@@ -601,11 +611,11 @@ def getCaseInfo(text: str):
 	except (IndexError, AttributeError):
 		pass
  
-	if bool(re.search(r'(?a)(VS\.|V\.{1})(.+)(Case)*', text, re.MULTILINE)) == True:
-		name = re.search(r'(?a)(VS\.|V\.{1})(.+)(Case)*', text, re.MULTILINE).group(2).replace("Case Number:","").strip()
+	if bool(re.search(r'(?a)(VS\.|V\.{1})(.{5,100})(Case)*', text, re.MULTILINE)) == True:
+		name = re.search(r'(?a)(VS\.|V\.{1})(.{5,100})(Case)*', text, re.MULTILINE).group(2).replace("Case Number:","").strip()
 	else:
-		if bool(re.search(r'(?:DOB)(.+)(?:Name)', text, re.MULTILINE)) == True:
-			name = re.search(r'(?:DOB)(.+)(?:Name)', text, re.MULTILINE).group(1).replace(":","").replace("Case Number:","").strip()
+		if bool(re.search(r'(?:DOB)(.{5,100})(?:Name)', text, re.MULTILINE)) == True:
+			name = re.search(r'(?:DOB)(.{5,100})(?:Name)', text, re.MULTILINE).group(1).replace(":","").replace("Case Number:","").strip()
 	if bool(re.search(r'(SSN).{5,75}?(Alias)',text, re.MULTILINE)) == True:
 		alias = re.search(r'(SSN)(.{5,75})(Alias)?', text, re.MULTILINE).group(2).replace(":","").replace("Alias 1","").strip()
 	else:
@@ -705,6 +715,9 @@ def getFeeSheet(text: str, cnum: str):
 
 
 		feesheet = feesheet.append(totalrdf, ignore_index=True)
+		feesheet['Code'] = feesheet['Code'].astype("category")
+		feesheet['Payor'] = feesheet['Payor'].astype("category")
+
 
 		try:
 			d999 = feesheet[feesheet['Code']=='D999']['Balance']
@@ -723,7 +736,7 @@ def getCharges(text: str, cnum: str):
 	ch = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{10,75})', str(text), re.MULTILINE)
 	c = []
 	for a in ch:
-		b = str(a).replace("Sentences","").replace("Sentence 1","").replace("SentencesSentence 1","").replace("Sentence","").replace("Financial","")
+		b = str(a).replace("Sentences","").replace("Sentence","").replace("SentencesSentence","").replace("Sentence","").replace("Financial","")
 		if b[-2:] == " 1" or b[-2:] == " 0":
 			b = b.replace(" 1","").replace(" 0","").strip()
 		if ":" in b:
@@ -753,7 +766,7 @@ def getCharges(text: str, cnum: str):
 		charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'(\d{1}.{2}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x).group())
 	except (AttributeError, IndexError):
 		try:
-			charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'(\d{1}.{2}-.{3}-.{3})',x).group())
+			charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'(.{3}-.{3}-.{3})',x).group())
 		except (AttributeError, IndexError):
 			charges['Cite'] = ""
 	charges['Cite'] = charges['Cite'].astype(str)
@@ -768,24 +781,6 @@ def getCharges(text: str, cnum: str):
 	except (AttributeError, IndexError):
 		pass
 
-	# try:
-	# 	charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x).group())
-	# except (AttributeError, IndexError):
-	# 	try:
-	# 		charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'(.{3}-.{3}-.{3})',x).group())
-	# 	except (AttributeError, IndexError):
-	# 		pass
-	# try:
-	# 	charges['parentheses'] = charges['Charges'].map(lambda x: re.search(r'(\([A-Z]\))', x).group())
-	# 	charges['Cite'] = charges['Cite'] + charges['parentheses']
-	# except (AttributeError, IndexError):
-	# 	pass
-	# try:
-	# 	charges['decimals'] = charges['Charges'].map(lambda x: re.search(r'(\.[0-9])', x).group())
-	# 	charges['Cite'] = charges['Cite'] + charges['decimals']
-	# except (AttributeError, IndexError):
-	# 	pass
-
 	charges['TypeDescription'] = charges['Charges'].map(lambda x: re.search(r'(BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', x).group() if bool(re.search(r'(BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', x)) else "")
 	charges['Category'] = charges['Charges'].map(lambda x: re.search(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', x).group() if bool(re.search(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', x)) else "")
 	charges['Description'] = charges['Charges'].map(lambda x: x[9:-1])
@@ -794,6 +789,11 @@ def getCharges(text: str, cnum: str):
 	charges['Description'] = charges['Description'].map(lambda x: x.replace("\'","").strip())
 	charges.drop(columns=['PardonCode','PermanentCode','CERVCode','VRRexception','parentheses','decimals'], inplace=True)
 
+	charges['Category'] = charges['Category'].astype("category")
+	charges['TypeDescription'] = charges['TypeDescription'].astype("category")
+	charges['Code'] = charges['Code'].astype("category")
+	charges['CourtAction'] = charges['CourtAction'].astype("category")
+
 	# counts
 	conviction_ct = charges[charges.Conviction == True].shape[0]
 	charge_ct = charges.shape[0]
@@ -833,13 +833,13 @@ def log_complete(conf, start_time):
 	cases_per_sec = case_max/elapsed
 	print(f'''
     ___    __                          __         
-   /   |  / /___ __________  _________/ /__  _____
+   /   |  / /___  _________  _________/ /__  _____
   / /| | / / __ `/ ___/ __ \\/ ___/ __  / _ \\/ ___/
  / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
 /_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																										
 	
-	ALACORDER beta 7.3.1
+	ALACORDER beta 7.3.7
 	by Sam Robson	
 
 	Searched {path_in} 
@@ -865,13 +865,13 @@ def console_log(conf, on_batch: int, last_log, to_str):
 	if plog == True:
 		print(f'''\n\n
 	    ___    __                          __         
-	   /   |  / /___ __________  _________/ /__  _____
+	   /   |  / /___  _________  _________/ /__  _____
 	  / /| | / / __ `/ ___/ __ \\/ ___/ __  / _ \\/ ___/
 	 / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
 	/_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																											
 		
-		ALACORDER beta 7.3.1
+		ALACORDER beta 7.3.7
 
 		Searching {path_in} 
 		{path_out} 
